@@ -272,8 +272,6 @@ class FeaturesAssembler(AbstractAssembler):
         shortcut_df = self.dbx.local_overwrite_and_load_pickle(folder='', subfolder='',
                                                       returns_pkl_file_name=self.shortcut_features_pkl_file_name,
                                                       local_root_directory=self.local_root_directory)
-        shortcut_df = shortcut_df[shortcut_df.index >= self.starting_date]
-        shortcut_df = shortcut_df[shortcut_df.index <= self.ending_date]
         return shortcut_df
 
     def preprocessReturns(self, lookback_window, ts_fresh_indices = ['SPXT'], add_signal_predictor = False):
@@ -432,6 +430,10 @@ class FeaturesAssembler(AbstractAssembler):
         np.random.seed(0)
         torch.manual_seed(0)
 
+        shortcut_features_df = self.preprocessShortcutFeatures()
+        shortcut_features_names = [col for col in list(shortcut_features_df.columns) if col!='Date']
+
+
         df_ret, strats, strat_features_names = self.preprocessReturns(tsfresh_lookback_window)
         print('Max price date before filtering'+str(max(df_ret.index)))
         print('Min price date before filtering'+str(min(df_ret.index)))
@@ -455,6 +457,15 @@ class FeaturesAssembler(AbstractAssembler):
         print('Min price date '+str(min(df_ret.index)))
 
 
+        print('Actual min shortcut feature date '+str(min(shortcut_features_df.index)))
+        print('Actual max shortcut feature date '+str(max(shortcut_features_df.index)))
+
+        shortcut_features_df = shortcut_features_df[shortcut_features_df.index >= self.starting_date]
+        shortcut_features_df = shortcut_features_df[shortcut_features_df.index <= self.ending_date]
+        print('Max shortcut date '+str(max(shortcut_features_df.index)))
+        print('Min shortcut date '+str(min(shortcut_features_df.index)))
+
+
         # quotes_df=quotes_df.sort_values(by='date', ascending=True)
         # quotes_df.head()
 
@@ -474,6 +485,8 @@ class FeaturesAssembler(AbstractAssembler):
 
         print('merging')
         df_ret = pd.merge(df_ret, advanced_features, how='left', on=['Date'])
+        df_ret = pd.merge(df_ret, shortcut_features_df, how='left', on=['Date'])
+
         df_ret = df_ret.replace([np.inf, -np.inf], np.nan)
         df_ret=df_ret.fillna(0.)
 
@@ -484,12 +497,18 @@ class FeaturesAssembler(AbstractAssembler):
         print('number of infs in advanced features')
         print(np.isinf(df_ret[features_names]).sum(axis=0))
 
+        print('number of infs in shortcut features')
+        print(np.isinf(df_ret[shortcut_features_names]).sum(axis=0))
+
         print('number of infs in returns')
         print(np.isinf(df_ret[strats]).sum(axis=0))
 
         print('number of nans in advanced features')
         print(np.isnan(df_ret[features_names]).sum(axis=0))
 
+        print('number of nans in shortcut features')
+        print(np.isnan(df_ret[shortcut_features_names]).sum(axis=0))
+
         print('number of nans in returns')
         print(np.isnan(df_ret[strats]).sum(axis=0))
 
